@@ -1,37 +1,37 @@
 $VAR1 = {
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'floodtime' => 10,
-          'version' => '0.74',
-          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'version' => '0.75',
           'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'admin' => {
-                       'email' => 'dirk.lze@gmail.com',
-                       'firstname' => 'Dirk',
-                       'password' => 'testpass',
-                       'name' => 'Lindner'
-                     },
-          'scriptAlias' => 'cgi-bin',
-          'cgi' => {
-                     'DocumentRoot' => '/var/www/htdocs',
-                     'bin' => '/var/www/cgi-bin',
-                     'serverName' => 'http://localhost',
-                     'expires' => '+1y',
-                     'cookiePath' => '/',
-                     'style' => 'mysql',
-                     'alias' => 'cgi-bin',
-                     'title' => 'MySQL::Admin'
-                   },
-          'language' => 'en',
           'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'language' => 'en',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
           'database' => {
-                          'CurrentHost' => 'localhost',
-                          'user' => 'root',
+                          'CurrentDb' => 'LZE',
+                          'name' => 'LZE',
+                          'host' => 'localhost',
+                          'CurrentPass' => 'keinz',
                           'CurrentUser' => 'root',
                           'password' => 'keinz',
-                          'name' => 'LZE',
-                          'CurrentPass' => 'keinz',
-                          'host' => 'localhost',
-                          'CurrentDb' => 'LZE'
-                        }
+                          'CurrentHost' => 'localhost',
+                          'user' => 'root'
+                        },
+          'cgi' => {
+                     'cookiePath' => '/',
+                     'title' => 'MySQL::Admin',
+                     'alias' => 'cgi-bin',
+                     'serverName' => 'http://localhost',
+                     'style' => 'mysql',
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'expires' => '+1y',
+                     'bin' => '/var/www/cgi-bin'
+                   },
+          'admin' => {
+                       'name' => 'Lindner',
+                       'email' => 'dirk.lze@gmail.com',
+                       'firstname' => 'Dirk',
+                       'password' => 'testpass'
+                     },
+          'scriptAlias' => 'cgi-bin',
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'floodtime' => 10
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
