@@ -1,145 +1,3 @@
-CREATE TABLE `actions` (
-  `action` varchar(100) NOT NULL DEFAULT '',
-  `file` varchar(100) NOT NULL DEFAULT '',
-  `title` varchar(100) NOT NULL DEFAULT '',
-  `right` int(1) NOT NULL DEFAULT '0',
-  `box` varchar(500) DEFAULT NULL,
-  `sub` varchar(25) NOT NULL DEFAULT 'main',
-  `id` int(11) NOT NULL AUTO_INCREMENT,
-  PRIMARY KEY (`id`)
-) ENGINE=MyISAM AUTO_INCREMENT=151 DEFAULT CHARSET=utf8;
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('showLogin','exploit.pl','','0','tables exploit','main','147');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddFulltext','tables.pl','AddFulltext','5','tables exploit','AddFulltext','62');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AnalyzeTable','tables.pl','AnalyzeTable','5','tables exploit','AnalyzeTable','63');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddPrimaryKey','tables.pl','AddPrimaryKey','5','tables exploit','AddPrimaryKey','64');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','tables exploit','ChangeEngine','65');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeAutoInCrementValue','5','tables exploit','ChangeAutoInCrementValue','66');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeCol','tables.pl','ChangeCol','5','tables exploit','ChangeCol','67');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','tables exploit','ChangeEngine','68');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeCharset','tables.pl','ChangeCharset','5','tables exploit','ChangeCharset','69');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeAutoInCrementValue','5','tables exploit','ChangeAutoInCrementValue','70');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChooseDataBase','tables.pl','ChooseDataBase','5','tables exploit','ChooseDataBase','71');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropTable','tables.pl','DropTable','5','tables exploit','DropTable','72');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DeleteEntry','tables.pl','DeleteEntry','5','tables exploit','DeleteEntry','73');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropCol','tables.pl','DropCol','5','tables exploit','DropCol','74');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDumpTable','tables.pl','DumpTable','5','tables exploit','ShowDumpTable','75');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ExecSql','tables.pl','ExecSql','5','tables exploit','ExecSql','76');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('EditTable','tables.pl','SQL','5','tables exploit','EditTable','77');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('EditEntry','tables.pl','EditEntry','5','tables exploit','EditEntry','78');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewEntry','tables.pl','NewEntry','5','tables exploit','NewEntry','79');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewTable','tables.pl','NewTable','5','tables exploit','NewTable','80');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('CreateDatabase','tables.pl','CreateDatabase','5','tables exploit','CreateDatabase','81');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('OptimizeTable','tables.pl','OptimizeTable','5','tables exploit','OptimizeTable','82');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('RepairTable','tables.pl','RepairTable','5','tables exploit','RepairTable','84');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveEditTable','tables.pl','SaveEditTable','5','tables exploit','SaveEditTable','85');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SQL','tables.pl','SQL','5','tables exploit','SQL','86');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowNewTable','tables.pl','ShowNewTable','5','tables exploit','ShowNewTable','87');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveEntry','tables.pl','SaveEntry','5','tables exploit','SaveEntry','88');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropFulltext','tables.pl','DropFulltext','5','tables exploit','DropFulltext','89');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowTables','tables.pl','ShowTables','5','tables exploit','ShowTables','90');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowTableDetails','tables.pl','ShowTableDetails','5','tables exploit','ShowTableDetails','91');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowTable','tables.pl','ShowTable','5','tables exploit','ShowTable','92');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('TruncateTable','tables.pl','TruncateTable','5','tables exploit','TruncateTable','93');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','ShowProcesslist','5','tables exploit','ShowProcesslist','94');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropFulltext','tables.pl','DropFulltext','5','tables exploit','DropFulltext','95');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddIndex','tables.pl','DropFulltext','5','tables exploit','AddIndex','96');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropIndex','tables.pl','DropFulltext','5','tables exploit','DropIndex','97');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddUnique','tables.pl','DropFulltext','5','tables exploit','AddUnique','98');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowNewEntry','tables.pl','ShowNewEntry','5','tables exploit','ShowNewEntry','99');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveEntry','tables.pl','SaveEntry','5','tables exploit','SaveEntry','100');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewEntry','tables.pl','NewEntry','5','tables exploit','NewEntry','101');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DeleteEntry','tables.pl','DeleteEntry','5','tables exploit','DeleteEntry','102');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('MultipleAction','tables.pl','MultipleAction','5','tables exploit','MultipleAction','104');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDumpDatabase','tables.pl','DumpDatabase','5','tables exploit','ShowDumpDatabase','105');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowNewTable','tables.pl','ShowNewTable','5','tables exploit','ShowNewTable','106');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewTable','tables.pl','SaveNewTable','5','tables exploit','SaveNewTable','107');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('EditAction','tables.pl','EditAction','5','tables exploit','EditAction','111');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('showProfile','tables.pl','showProfile','5','tables exploit','showProfile','148');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('MultipleDbAction','tables.pl','MultipleDbAction','5','tables exploit','MultipleDbAction','118');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('RenameTable','tables.pl','RenameTable','5','tables exploit','RenameTable','119');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewColumn','tables.pl','SaveNewColumn','5','tables exploit','SaveNewColumn','120');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewDatabase','tables.pl','NewDatabase','5','tables exploit','NewDatabase','121');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowEditIndex','tables.pl','ShowEditIndex','5','tables exploit','ShowEditIndex','122');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewIndex','tables.pl','SaveNewIndex','5','tables exploit','SaveNewIndex','123');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','tables exploit','ChangeEngine','124');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeEngine','5','tables exploit','ChangeAutoInCrementValue','125');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowRights','tables.pl','ShowRights','5','tables exploit','ShowRights','127');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveRights','tables.pl','SaveRights','5','tables exploit','SaveRights','128');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowUsers','tables.pl','ShowUsers','5','tables exploit','ShowUsers','129');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('CreateUser','tables.pl','CreateUser','5','tables exploit','CreateUser','130');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DeleteUser','tables.pl','DeleteUser','5','tables exploit','DeleteUser','131');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropDatabase','tables.pl','DropDatabase','5','tables exploit','DropDatabase','132');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDatabases','tables.pl','ShowDatabases','5','tables exploit','ShowDatabases','133');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','ShowProcesslist','5','tables exploit','ShowProcesslist','134');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowVariables','tables.pl','ShowVariables','5','tables exploit','ShowVariables','135');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('translate','translate.pl','translate','5','tables exploit','main','141');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','processlist','5','tables exploit','ShowProcesslist','143');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowVariables','tables.pl','ShowVariables','5','tables exploit','ShowVariables','144');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('searchDatabase','tables.pl','searchDatabase','5','tables exploit','searchDatabase','145');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('saveProfile','tables.pl','Profile','5','tables exploit','saveProfile','149');
-INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('searchHelpTopic','tables.pl','Help Topic','5','tables exploit','searchHelpTopic','150');
-
-CREATE TABLE `box` (
-  `file` varchar(100) NOT NULL,
-  `right` int(1) NOT NULL DEFAULT '0',
-  `name` varchar(100) NOT NULL,
-  `outId` varchar(100) NOT NULL DEFAULT 'content',
-  `id` int(11) NOT NULL AUTO_INCREMENT,
-  PRIMARY KEY (`id`)
-) ENGINE=MyISAM AUTO_INCREMENT=12 DEFAULT CHARSET=utf8;
-INSERT INTO `box` (`file`,`right`,`name`,`outId`,`id`) values('tables.pl','5','database','menuBar','10');
-INSERT INTO `box` (`file`,`right`,`name`,`outId`,`id`) values('exploit.pl','0','exploit','content','11');
-
-CREATE TABLE `exploit` (
-  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
-  `referer` text NOT NULL,
-  `remote_addr` text NOT NULL,
-  `query_string` text NOT NULL,
-  `id` int(11) NOT NULL AUTO_INCREMENT,
-  `count` int(11) NOT NULL,
-  PRIMARY KEY (`id`),
-  UNIQUE KEY `id` (`id`),
-  FULLTEXT KEY `remote_addr` (`remote_addr`)
-) ENGINE=MyISAM AUTO_INCREMENT=31 DEFAULT CHARSET=utf8;
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 17:45:07','http://localhost/?/cgi-bin/mysql.pl?action=logout','127.0.0.1','','1','4');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 03:04:28','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=02e9278a94e4f1ad04cf64d25bf3d9b6&captcha=r71&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=02e9278a94e4f1ad04cf64d25bf3d9b6;captcha=r71;submit=save','22','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 18:42:41','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=4ac2a6b63018dd5f403396062ec78cc7&captcha=fxm&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=4ac2a6b63018dd5f403396062ec78cc7;captcha=fxm;submit=save','3','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 22:02:47','http://localhost/?cgi-bin/mysql.pl?action=showDatabases','127.0.0.1','action=showDatabases','4','23');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 18:43:38','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=1656e9258cb5af8f619c23c46fa292d2&captcha=hj3&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=1656e9258cb5af8f619c23c46fa292d2;captcha=hj3;submit=save','5','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 18:43:58','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=a40cf64504dcdd28df465cfc62d04063&captcha=7jb&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=a40cf64504dcdd28df465cfc62d04063;captcha=7jb;submit=save','6','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 18:44:10','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=af722a11bb6935200d134f8403c4cb27&captcha=gfb&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=af722a11bb6935200d134f8403c4cb27;captcha=gfb;submit=save','7','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 18:46:27','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=ab62607c854ee15b7778ec0827ed1bd5&captcha=ej6&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=ab62607c854ee15b7778ec0827ed1bd5;captcha=ej6;submit=save','8','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 18:53:38','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=e2683476d2c1b6c9f4e99609ac6748c6&captcha=7ew&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=e2683476d2c1b6c9f4e99609ac6748c6;captcha=7ew;submit=save','9','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 19:01:22','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=51da9dd55d318e05f3c83dbc0eea6388&captcha=i3d&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=51da9dd55d318e05f3c83dbc0eea6388;captcha=i3d;submit=save','10','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 19:01:32','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=a2f1ddf660ccf5c4e7a75a50250ffea3&captcha=pmp&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=a2f1ddf660ccf5c4e7a75a50250ffea3;captcha=pmp;submit=save','11','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-08 17:31:18','http://localhost/?cgi-bin/mysql.pl?action=ShowTables','127.0.0.1','action=ShowTables','12','4');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 19:37:47','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=34da8fdc815dc88c5498cd0e6ebcc356&captcha=55I&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=34da8fdc815dc88c5498cd0e6ebcc356;captcha=55I;submit=save','13','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 22:31:03','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=1f564695e21cb7bb3beebc8ea3a15b56&captcha=hxp&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=1f564695e21cb7bb3beebc8ea3a15b56;captcha=hxp;submit=save','14','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 23:16:39','http://localhost/?/cgi-bin/mysql.pl?action=EditTable&table=actions','127.0.0.1','action=EditTable;amp=;table=actions','15','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 23:16:55','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpasstestpass&md5=68a0d9bf72e49950ea089e83f873430f&captcha=ad5&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpasstestpass;md5=68a0d9bf72e49950ea089e83f873430f;captcha=ad5;submit=save','16','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-08 09:03:11','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=f27f973bf9951eedcc9985ff9e0bcb6f&captcha=eqk&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=f27f973bf9951eedcc9985ff9e0bcb6f;captcha=eqk;submit=save','17','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-08 09:03:21','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=6d3adaab6ed768ba6c14f40bb04ef8f3&captcha=7Io&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=6d3adaab6ed768ba6c14f40bb04ef8f3;captcha=7Io;submit=save','18','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-08 11:23:27','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=2becd79f047cbcc16897546fd4625849&captcha=e2v&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=2becd79f047cbcc16897546fd4625849;captcha=e2v;submit=save','19','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-08 11:23:37','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=e0ea34315d6c03df0a44709b2d162733&captcha=is3&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=e0ea34315d6c03df0a44709b2d162733;captcha=is3;submit=save','20','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-08 14:28:36','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpassoldpass&md5=49d8d3ab8d7f26fa1334754769459024&captcha=dsy&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpassoldpass;md5=49d8d3ab8d7f26fa1334754769459024;captcha=dsy;submit=save','21','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 04:46:42','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=1e8193e45969453378cd1d6c1e3ccb88&captcha=fao&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=1e8193e45969453378cd1d6c1e3ccb88;captcha=fao;submit=save','23','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 04:47:15','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpassoldpass&md5=318e5060750aaec244ebdcb279d62a9c&captcha=4c5&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpassoldpass;md5=318e5060750aaec244ebdcb279d62a9c;captcha=4c5;submit=save','24','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 04:54:09','http://localhost/?/cgi-bin/mysql.pl?action=ShowTable&table=actions&ajax=true','127.0.0.1','action=ShowTable;table=actions;ajax=true','25','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 06:11:52','http://localhost/?/cgi-bin/mysql.pl?action=EditTable&table=box','127.0.0.1','action=EditTable;amp=;table=box','26','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 19:37:56','http://localhost/?/cgi-bin/mysql.pl?action=searchHelpTopic&topic=help_topic','127.0.0.1','action=searchHelpTopic;topic=help_topic','27','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 19:46:30','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpassoldpass&md5=6d89700735ba409796f157524d080c63&captcha=c5p&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpassoldpass;md5=6d89700735ba409796f157524d080c63;captcha=c5p;submit=save','28','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 19:46:39','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpassoldpass&md5=527b2b4e430b967a31f55eaa8a5b5364&captcha=8pf&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpassoldpass;md5=527b2b4e430b967a31f55eaa8a5b5364;captcha=8pf;submit=save','29','1');
-INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 22:02:25','http://localhost/?/cgi-bin/mysql.pl?action=ShowTable&table=box&desc=0','127.0.0.1','action=ShowTable;table=box;desc=0','30','2');
-
-CREATE TABLE `querys` (
-  `title` varchar(100) NOT NULL DEFAULT '',
-  `description` text NOT NULL,
-  `sql` text NOT NULL,
-  `return` varchar(100) NOT NULL DEFAULT 'fetch_array',
-  `id` int(11) NOT NULL AUTO_INCREMENT,
-  PRIMARY KEY (`id`)
-) ENGINE=MyISAM DEFAULT CHARSET=utf8;
-
 CREATE TABLE `reserved_words` (
   `reserved_word` varchar(50) DEFAULT NULL,
   `id` int(11) NOT NULL AUTO_INCREMENT,
@@ -369,6 +227,88 @@ INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARYING','221');
 INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WHILE','222');
 INSERT INTO `reserved_words` (`reserved_word`,`id`) values('XOR','223');
 
+CREATE TABLE `actions` (
+  `action` varchar(100) NOT NULL,
+  `file` varchar(100) NOT NULL,
+  `title` varchar(100) NOT NULL,
+  `right` int(1) NOT NULL DEFAULT '0',
+  `box` varchar(500) DEFAULT NULL,
+  `sub` varchar(25) NOT NULL DEFAULT 'main',
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  PRIMARY KEY (`id`),
+  KEY `action` (`action`)
+) ENGINE=MyISAM AUTO_INCREMENT=151 DEFAULT CHARSET=utf8;
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('showLogin','exploit.pl','','0','tables exploit','main','147');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddFulltext','tables.pl','AddFulltext','5','tables exploit','AddFulltext','62');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AnalyzeTable','tables.pl','AnalyzeTable','5','tables exploit','AnalyzeTable','63');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddPrimaryKey','tables.pl','AddPrimaryKey','5','tables exploit','AddPrimaryKey','64');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','tables exploit','ChangeEngine','65');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeAutoInCrementValue','5','tables exploit','ChangeAutoInCrementValue','66');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeCol','tables.pl','ChangeCol','5','tables exploit','ChangeCol','67');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','tables exploit','ChangeEngine','68');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeCharset','tables.pl','ChangeCharset','5','tables exploit','ChangeCharset','69');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeAutoInCrementValue','5','tables exploit','ChangeAutoInCrementValue','70');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChooseDataBase','tables.pl','ChooseDataBase','5','tables exploit','ChooseDataBase','71');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropTable','tables.pl','DropTable','5','tables exploit','DropTable','72');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DeleteEntry','tables.pl','DeleteEntry','5','tables exploit','DeleteEntry','73');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropCol','tables.pl','DropCol','5','tables exploit','DropCol','74');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDumpTable','tables.pl','DumpTable','5','tables exploit','ShowDumpTable','75');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ExecSql','tables.pl','ExecSql','5','tables exploit','ExecSql','76');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('EditTable','tables.pl','SQL','5','tables exploit','EditTable','77');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('EditEntry','tables.pl','EditEntry','5','tables exploit','EditEntry','78');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewEntry','tables.pl','NewEntry','5','tables exploit','NewEntry','79');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewTable','tables.pl','NewTable','5','tables exploit','NewTable','80');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('CreateDatabase','tables.pl','CreateDatabase','5','tables exploit','CreateDatabase','81');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('OptimizeTable','tables.pl','OptimizeTable','5','tables exploit','OptimizeTable','82');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('RepairTable','tables.pl','RepairTable','5','tables exploit','RepairTable','84');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveEditTable','tables.pl','SaveEditTable','5','tables exploit','SaveEditTable','85');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SQL','tables.pl','SQL','5','tables exploit','SQL','86');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowNewTable','tables.pl','ShowNewTable','5','tables exploit','ShowNewTable','87');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveEntry','tables.pl','SaveEntry','5','tables exploit','SaveEntry','88');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropFulltext','tables.pl','DropFulltext','5','tables exploit','DropFulltext','89');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowTables','tables.pl','ShowTables','5','tables exploit','ShowTables','90');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowTableDetails','tables.pl','ShowTableDetails','5','tables exploit','ShowTableDetails','91');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowTable','tables.pl','ShowTable','5','tables exploit','ShowTable','92');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('TruncateTable','tables.pl','TruncateTable','5','tables exploit','TruncateTable','93');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','ShowProcesslist','5','tables exploit','ShowProcesslist','94');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropFulltext','tables.pl','DropFulltext','5','tables exploit','DropFulltext','95');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddIndex','tables.pl','DropFulltext','5','tables exploit','AddIndex','96');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropIndex','tables.pl','DropFulltext','5','tables exploit','DropIndex','97');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddUnique','tables.pl','DropFulltext','5','tables exploit','AddUnique','98');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowNewEntry','tables.pl','ShowNewEntry','5','tables exploit','ShowNewEntry','99');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveEntry','tables.pl','SaveEntry','5','tables exploit','SaveEntry','100');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewEntry','tables.pl','NewEntry','5','tables exploit','NewEntry','101');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DeleteEntry','tables.pl','DeleteEntry','5','tables exploit','DeleteEntry','102');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('MultipleAction','tables.pl','MultipleAction','5','tables exploit','MultipleAction','104');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDumpDatabase','tables.pl','DumpDatabase','5','tables exploit','ShowDumpDatabase','105');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowNewTable','tables.pl','ShowNewTable','5','tables exploit','ShowNewTable','106');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewTable','tables.pl','SaveNewTable','5','tables exploit','SaveNewTable','107');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('EditAction','tables.pl','EditAction','5','tables exploit','EditAction','111');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('showProfile','tables.pl','showProfile','5','','showProfile','148');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('MultipleDbAction','tables.pl','MultipleDbAction','5','tables exploit','MultipleDbAction','118');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('RenameTable','tables.pl','RenameTable','5','tables exploit','RenameTable','119');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewColumn','tables.pl','SaveNewColumn','5','tables exploit','SaveNewColumn','120');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewDatabase','tables.pl','NewDatabase','5','tables exploit','NewDatabase','121');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowEditIndex','tables.pl','ShowEditIndex','5','tables exploit','ShowEditIndex','122');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewIndex','tables.pl','SaveNewIndex','5','tables exploit','SaveNewIndex','123');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','tables exploit','ChangeEngine','124');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeEngine','5','tables exploit','ChangeAutoInCrementValue','125');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowRights','tables.pl','ShowRights','5','tables exploit','ShowRights','127');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveRights','tables.pl','SaveRights','5','tables exploit','SaveRights','128');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowUsers','tables.pl','ShowUsers','5','tables exploit','ShowUsers','129');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('CreateUser','tables.pl','CreateUser','5','tables exploit','CreateUser','130');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DeleteUser','tables.pl','DeleteUser','5','tables exploit','DeleteUser','131');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropDatabase','tables.pl','DropDatabase','5','tables exploit','DropDatabase','132');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDatabases','tables.pl','ShowDatabases','5','tables exploit','ShowDatabases','133');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','ShowProcesslist','5','tables exploit','ShowProcesslist','134');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowVariables','tables.pl','ShowVariables','5','tables exploit','ShowVariables','135');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('translate','translate.pl','translate','5','tables exploit','main','141');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','processlist','5','tables exploit','ShowProcesslist','143');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowVariables','tables.pl','ShowVariables','5','tables exploit','ShowVariables','144');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('searchDatabase','tables.pl','searchDatabase','5','tables exploit','searchDatabase','145');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('saveProfile','tables.pl','Profile','5','tables exploit','saveProfile','149');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('searchHelpTopic','tables.pl','Help Topic','5','tables exploit','searchHelpTopic','150');
+
 CREATE TABLE `users` (
   `pass` text NOT NULL,
   `user` varchar(10) NOT NULL,
@@ -380,3 +320,45 @@ CREATE TABLE `users` (
 ) ENGINE=MyISAM AUTO_INCREMENT=7 DEFAULT CHARSET=utf8;
 INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('guest','guest','0','123','dd','1');
 
+CREATE TABLE `box` (
+  `file` varchar(100) NOT NULL,
+  `right` int(1) NOT NULL DEFAULT '0',
+  `name` varchar(100) NOT NULL,
+  `outId` varchar(100) NOT NULL DEFAULT 'content',
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  PRIMARY KEY (`id`)
+) ENGINE=MyISAM AUTO_INCREMENT=12 DEFAULT CHARSET=utf8;
+INSERT INTO `box` (`file`,`right`,`name`,`outId`,`id`) values('tables.pl','5','database','menuBar','10');
+INSERT INTO `box` (`file`,`right`,`name`,`outId`,`id`) values('exploit.pl','0','exploit','content','11');
+
+CREATE TABLE `testtabelle` (
+  `a` text NOT NULL,
+  `b` varchar(25) NOT NULL,
+  `c` int(11) NOT NULL,
+  `d` int(11) NOT NULL,
+  `e` int(11) NOT NULL,
+  `f` int(11) NOT NULL,
+  PRIMARY KEY (`b`)
+) ENGINE=MyISAM DEFAULT CHARSET=big5;
+
+CREATE TABLE `querys` (
+  `title` varchar(100) NOT NULL DEFAULT '',
+  `description` text NOT NULL,
+  `sql` text NOT NULL,
+  `return` varchar(100) NOT NULL DEFAULT 'fetch_array',
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  PRIMARY KEY (`id`)
+) ENGINE=MyISAM DEFAULT CHARSET=utf8;
+
+CREATE TABLE `exploit` (
+  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
+  `referer` text NOT NULL,
+  `remote_addr` text NOT NULL,
+  `query_string` text NOT NULL,
+  `id` int(11) NOT NULL AUTO_INCREMENT,
+  `count` int(11) NOT NULL,
+  PRIMARY KEY (`id`),
+  UNIQUE KEY `id` (`id`),
+  FULLTEXT KEY `remote_addr` (`remote_addr`)
+) ENGINE=MyISAM DEFAULT CHARSET=utf8;
+
