@@ -4,14 +4,14 @@ function init(){
 	loadHistory();
 	translate();
 }
-// function alert(txt){
-// 	visible('popup');
-//         setText('popupContent','<div align="center">'+txt+'<br/><input  type="submit" id="confirmButton" value="Ok"/></div>');
-// 	var node = $("confirmButton");
-// 	node.addEventListener('click', function (evt){
-// 	  hide('popup');
-// 	});
-// }
+function alert(txt){
+	visible('popup');
+	setText('popupContent','<div align="center">'+txt+'<br/><input  type="submit" id="confirmButton" value="Ok"/></div>');
+	var node = $("confirmButton");
+	node.addEventListener('click', function (evt){
+	  hide('popup');
+	});
+}
 function confirm2(txt,sub,arg,arg2,arg3){
 	visible('popup');
 	var sleep = true;
@@ -399,8 +399,27 @@ if (navigator.userAgent.indexOf("Firefox")!=-1)
 function $(id){
     return document.getElementById(id);
 }
+
 var autocomplete = new Array("select","from","where","insert","set","update");
+var clickA;
+var oldDate;
+var oldTime;
+
+function breakOut(){
+  clickA = clickA ?false:true;
+  if(clickA){
+    oldDate = new Date();
+    oldTime = oldDate.getTime();
+    return false;
+  }else{
+    var date = new Date();
+    var time = date.getTime();
+    return (time - oldTime > 1000) ? false : true;
+  }
+}
 function Autocomplete(evt){
+  if(breakOut())
+      return;
   if (evt.which == 8 ||evt.which == 16||  evt.which === 37 || evt.which === 38 ||evt.which === 39 || evt.which === 39 || evt.which === 40  )
     return;
     var offset = 3;
@@ -426,6 +445,7 @@ function Autocomplete(evt){
 	offset++;
       }
 }
+
 function selKeyword(id){
   for(var i= 0; i<  $(id).options.length;i++ )
       autocomplete.push( $(id).options[i].value.toLowerCase());
@@ -444,14 +464,16 @@ function showSQLEditor(){
   }
   uno = false;
 }
+
 function ShowNewRow(){
   $('popupContent1').style.left='2%';
   $('popupContent1').style.width='96%';
   showPopup('ShowNewRow');
 }
+
 function insertAtCursorPosition(txt){
        var textarea  = document.getElementById('sqlEdit');
-       if(typeof document.selection != 'undefined'){ //IE6
+       if(typeof document.selection != 'undefined'){
               range = document.selection.createRange();
               var txt = range.text;
 	      range.text = txt;
@@ -466,17 +488,21 @@ function insertAtCursorPosition(txt){
              textarea.value += txt;	
        }
 }
+
 var timer;
 function toolbarOver(){
     timer = setTimeout(function lol(){showToolbar('toolbar');showToolbar('toolbar2');},300)
 }
+
 function toolbarOut(){
    clearTimeout(timer);
 }
+
 function closeToolbar(){
     hideToolbar('toolbar2');
     hideToolbar('toolbar');
 }
+
 function showToolbar(id){
   var entry = $(id);
   if(entry && entry.firstChild){
@@ -485,10 +511,13 @@ function showToolbar(id){
 	  entry.firstChild.style.display ='';
   }
   var node = $('toolbarTable');
-  node.addEventListener ('mouseleave', function (evt) {
-  closeToolbar();
-  });
+  if(node){
+    node.addEventListener ('mouseleave', function (evt) {
+    closeToolbar();
+    });
+  }
 }
+
 function hideToolbar(id){
   var entry = $(id);
   if(entry && entry.firstChild){
