@@ -19,19 +19,19 @@ use DBI::Library qw(:all $m_dbh $m_dsn);
 @DBI::Library::Database::ISA    = qw(DBI::Library Exporter);
 @DBI::Library::Database::EXPORT = qw(useexecute);
 @DBI::Library::Database::EXPORT_OK =
-  qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver execute useexecute quote void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists addUser hasAcount isMember right getAction checkPass checkSession setSid getName initDB checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string);
+  qw(getIndex getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver execute useexecute quote void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists addUser hasAcount isMember right getAction checkPass checkSession setSid getName initDB checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string);
 %DBI::Library::Database::EXPORT_TAGS = (
     'all' => [
-        qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right getAction checkPass checkSession setSid getName initDB tableLength tableExists useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute  checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string)
+        qw(getIndex getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right getAction checkPass checkSession setSid getName initDB tableLength tableExists useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute  checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string)
     ],
     'dynamic' => [qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute)],
     'independent' =>
       [qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute fetch_string)],
     'lze' => [
-        qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right getAction checkPass checkSession setSid getName checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue)
+        qw(getIndex getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right getAction checkPass checkSession setSid getName checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue)
     ],
 );
-$DBI::Library::Database::VERSION = '0.74';
+$DBI::Library::Database::VERSION = '0.75';
 $m_nSecs                         = 10;
 
 =head1 NAME
@@ -434,6 +434,34 @@ sub GetPrimaryKey
     }
 }
 
+=head2 getIndex()
+
+
+=cut
+
+sub getIndex
+{
+    my ($self, @p) = getSelf(@_);
+    my $tbl = $p[0];
+    if (defined $tbl){
+        $tbl = $m_dbh->quote_identifier($tbl);
+	my $hr =   $self->fetch_hashref("SHOW CREATE TABLE $tbl");
+	my @return;
+	foreach my $line ( split /\n/,$hr->{'Create Table'}){
+	    if($line =~/(FULLTEXT KEY|UNIQUE KEY|KEY) `(.+)` \((.+)\)/){
+	      my $type = $1;
+	      my $name = $2;
+	      push @return, {
+		  field =>  /^`(.+)`$/,
+		  name  => $name,
+		  type  => $type,
+	      } for split /,/ , $3;
+	    }
+	}
+	return @return;
+    }
+}
+
 =head2 GetAutoIncrement()
 
        liefert die auto_increment zeile zurueck
@@ -565,7 +593,7 @@ sub GetEngines
     if (defined $tbl) {
         my @co     = $self->fetch_AoH('SHOW ENGINES');
         my $status = $self->fetch_hashref('SHOW TABLE STATUS where `Name` = ? ', $tbl);
-        my $return = qq|<select name="$name">|;
+        my $return = qq|<select class="ediTable" name="$name">|;
         $return .=
           $_->{Engine} eq $status->{Engine}
           ? qq|<option  value="$_->{Engine}"  selected="selected" >$_->{Engine}</option>|
@@ -592,7 +620,7 @@ sub GetEngineForRow
     if (defined $tbl && defined $name) {
         my @co       = $self->fetch_array('SHOW ENGINES');
         my @EINGINES = $self->fetch_AoH('SHOW TABLE STATUS where `Name` = ?  ', $tbl);
-        my $return   = qq|<select name="$name">|;
+        my $return   = qq|<select class="ediTable" name="$name">|;
         $return .=
           $_->{Engine} eq "@co"
           ? qq|<option  value="$_->{Engine}"  selected="selected" >$_->{Engine}</option>|
@@ -619,7 +647,7 @@ sub GetNull
     my $null = shift @p;
     my $name = shift @p;
     if (defined $null && defined $name) {
-        my $return = qq|<select name="$name">|;
+        my $return = qq|<select class="ediTable" name="$name">|;
         $return .= qq|<option  value="not NULL">not NULL</option>|;
         $return .=
           $null eq 'YES'
@@ -646,7 +674,7 @@ sub GetExtra
     my $selected = shift @p;
     my $name     = shift @p;
     if (defined $selected && defined $name) {
-        my $return = qq|<select name="$name">|;
+        my $return = qq|<select class="ediTable" name="$name">|;
         $return .= '<option value=""></option>';
         $return .=
           $selected eq "auto_increment"
@@ -674,7 +702,7 @@ sub GetTypes
     my $name = shift @p;
     $type =~ s/(\w+).*/uc $1/eg;
     if (defined $type && defined $name) {    #todo title setzen
-        my $return = qq|<select name="$name">|;
+        my $return = qq|<select class="ediTable" name="$name">|;
         $return .= '<option></option>';
         $return .=
           $type eq 'TINYINT'
@@ -777,7 +805,7 @@ sub GetColumnCollation
         $tbl = $m_dbh->quote_identifier($tbl);
         my $col       = $self->fetch_hashref("show full columns from $tbl where field = ?", $column);
         my @collation = $self->fetch_AoH("SHOW COLLATION");
-        my $return    = qq|<select name="$name" style="width:100px;"><option></option>|;
+        my $return    = qq|<select class="ediTable" name="$name" style="width:100px;"><option></option>|;
         unless ($col->{Collation}) {
             $return .= qq|<option  value="NULL"  selected="selected" >NULL</option>|;
         } else {
@@ -813,7 +841,7 @@ sub GetCollation
             $selected = $a[$i]->{Collation} if ($a[$i]->{Name} eq $selected);
         }
     }
-    my $return = qq|<select name="$name" style="width:100px;"><option></option>|;
+    my $return = qq|<select class="ediTable" name="$name" style="width:100px;"><option></option>|;
     $return .= qq|<option  value="$_->{Collation}"| . ($selected eq $_->{Collation} ? 'selected="selected"' : '') . qq|>$_->{Collation}</option>| foreach @collation;
     $return .= '</select>';
     return $return;
@@ -838,7 +866,7 @@ sub GetCharset
         }
         }
         $selected = GetCharacterSet($selected );
-    my $return = qq|<select name="$name" style="width:100px;"><option></option>|;
+    my $return = qq|<select class="ediTable" name="$name" style="width:100px;"><option></option>|;
     $return .= qq|<option  value="$_->{Charset}"| . ($selected eq $_->{Charset} ? 'selected="selected"' : '') . qq|>$_->{Charset}</option>| foreach @Charset;
     $return .= '</select>';
     return $return;
@@ -858,7 +886,7 @@ sub GetAttrs
     my $name   = shift @p;
     if ($tbl) {
         my $hr     = $self->fetch_hashref("SHOW CREATE TABLE $tbl");
-        my $return = qq|<select name="$name" style="width:100px;">
+        my $return = qq|<select class="ediTable" name="$name" style="width:100px;">
     <option ></option>
     <option  value="UNSIGNED" |
           . (
@@ -884,7 +912,7 @@ sub GetAttrs
         return $return;
     } else {
         return qq(
-    <select name="$name" style="width:100px;">
+    <select class="ediTable" name="$name" style="width:100px;">
     <option ></option>
     <option  value="UNSIGNED" ) .                    ($select eq 'UNSIGNED'                    ? 'selected="selected"' : '') . q(>UNSIGNED</option>
     <option  value="UNSIGNED ZEROFILL" ) .           ($select eq 'UNSIGNED ZEROFILL'           ? 'selected="selected"' : '') . q(>UNSIGNED ZEROFILL</option>
@@ -906,7 +934,7 @@ sub GetColumns
     my $name     = shift @p;
     my $selected = shift @p;
     my @col      = $self->fetch_AoH("show columns from $tbl");
-    my $return   = qq|<select name="$name" style="width:100px;">|;
+    my $return   = qq|<select class="ediTable" name="$name" style="width:100px;">|;
     $return .= qq|<option  value="$_->{Field}" | . ($selected eq $_->{Field} ? 'selected="selected"' : '') . qq|>$_->{Field}</option>| foreach @col;
     $return .= '</select>';
     return $return;
@@ -977,7 +1005,7 @@ Dirk Lindner <lze@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2005-2009 by Hr. Dirk Lindner
+Copyright (C) 2005-2015 by Hr. Dirk Lindner
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public License
